==> addon-manager-impl-2.12.0.Final-sources.jar: org/jboss/forge/addon/manager/impl/ui/AddonListCommand.java <==
package org.jboss.forge.addon.manager.impl.ui;

import java.util.Iterator;
import java.util.Set;
import java.util.TreeSet;

import javax.inject.Inject;

import org.jboss.forge.addon.ui.command.AbstractUICommand;
import org.jboss.forge.addon.ui.context.UIBuilder;
import org.jboss.forge.addon.ui.context.UIContext;
import org.jboss.forge.addon.ui.context.UIExecutionContext;
import org.jboss.forge.addon.ui.output.UIOutput;
import org.jboss.forge.addon.ui.result.Result;
import org.jboss.forge.addon.ui.result.Results;
import org.jboss.forge.addon.ui.util.Categories;
import org.jboss.forge.addon.ui.util.Metadata;
import org.jboss.forge.furnace.Furnace;
import org.jboss.forge.furnace.addons.AddonId;
import org.jboss.forge.furnace.repositories.AddonRepository;

public class AddonListCommand extends AbstractUICommand implements AddonCommandConstants
{

   @Inject
   private Furnace furnace;

   @Override
   public Metadata getMetadata(UIContext context)
   {
      return Metadata.from(super.getMetadata(context), getClass())
               .name(ADDON_LIST_COMMAND_NAME)
               .description(ADDON_LIST_COMMAND_DESCRIPTION)
               .category(Categories.create(ADDON_MANAGER_CATEGORIES));
   }

   @Override
   public void initializeUI(UIBuilder builder) throws Exception
   {
   }

   @Override
   public Result execute(UIExecutionContext context) throws Exception
   {
      Set<AddonId> choices = new TreeSet<>();
      for (AddonRepository repository : furnace.getRepositories())
      {
         for (AddonId id : repository.listEnabled())
         {
            choices.add(id);
         }
      }

      Iterator<AddonId> iterator = choices.iterator();
      StringBuilder builder = new StringBuilder();
      while (iterator.hasNext())
      {
         AddonId addonId = iterator.next();
         builder.append(addonId.toCoordinates());

         if (iterator.hasNext())
            builder.append("\n");
      }
      UIOutput output = context.getUIContext().getProvider().getOutput();
      output.out().println("Currently installed addons:");
      output.out().println(builder.toString());
      return Results.success();
   }

   @Override
   public boolean isEnabled(UIContext context)
   {
      return !context.getProvider().isGUI();
   }
}

==> addon-manager-impl-3.10.0.Final-sources.jar: org/jboss/forge/addon/manager/impl/ui/AddonListCommand.java <==
/**
 * Copyright 2016 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Eclipse Public License version 1.0, available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.jboss.forge.addon.manager.impl.ui;

import java.io.PrintStream;
import java.util.Set;
import java.util.TreeSet;

import org.jboss.forge.addon.ui.command.AbstractUICommand;
import org.jboss.forge.addon.ui.context.UIBuilder;
import org.jboss.forge.addon.ui.context.UIContext;
import org.jboss.forge.addon.ui.context.UIExecutionContext;
import org.jboss.forge.addon.ui.output.UIOutput;
import org.jboss.forge.addon.ui.result.Result;
import org.jboss.forge.addon.ui.result.Results;
import org.jboss.forge.addon.ui.util.Categories;
import org.jboss.forge.addon.ui.util.Metadata;
import org.jboss.forge.furnace.Furnace;
import org.jboss.forge.furnace.addons.AddonId;
import org.jboss.forge.furnace.container.simple.lifecycle.SimpleContainer;
import org.jboss.forge.furnace.repositories.AddonRepository;

public class AddonListCommand extends AbstractUICommand implements AddonCommandConstants
{

   @Override
   public Metadata getMetadata(UIContext context)
   {
      return Metadata.from(super.getMetadata(context), getClass())
               .name(ADDON_LIST_COMMAND_NAME)
               .description(ADDON_LIST_COMMAND_DESCRIPTION)
               .category(Categories.create(ADDON_MANAGER_CATEGORIES));
   }

   @Override
   public void initializeUI(UIBuilder builder) throws Exception
   {
   }

   @Override
   public Result execute(UIExecutionContext context) throws Exception
   {
      Furnace furnace = SimpleContainer.getFurnace(getClass().getClassLoader());
      Set<AddonId> choices = new TreeSet<>();
      for (AddonRepository repository : furnace.getRepositories())
      {
         choices.addAll(repository.listEnabled());
      }
      UIOutput output = context.getUIContext().getProvider().getOutput();
      PrintStream out = output.out();
      out.println("Currently installed addons:");
      for (AddonId addonId : choices)
      {
         out.println(addonId.toCoordinates());
      }
      return Results.success();
   }

   @Override
   public boolean isEnabled(UIContext context)
   {
      return !context.getProvider().isGUI();
   }
}
